==> zio-aws-ssm_2.13-5.17.212.1-sources.jar: zio/aws/ssm/model/GetMaintenanceWindowTaskRequest.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.{
  MaintenanceWindowTaskId,
  MaintenanceWindowId
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetMaintenanceWindowTaskRequest(
    windowId: MaintenanceWindowId,
    windowTaskId: MaintenanceWindowTaskId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.GetMaintenanceWindowTaskRequest = {
    import GetMaintenanceWindowTaskRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.GetMaintenanceWindowTaskRequest
      .builder()
      .windowId(MaintenanceWindowId.unwrap(windowId): java.lang.String)
      .windowTaskId(
        MaintenanceWindowTaskId.unwrap(windowTaskId): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.GetMaintenanceWindowTaskRequest.ReadOnly =
    zio.aws.ssm.model.GetMaintenanceWindowTaskRequest.wrap(buildAwsValue())
}
object GetMaintenanceWindowTaskRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.GetMaintenanceWindowTaskRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.GetMaintenanceWindowTaskRequest =
      zio.aws.ssm.model.GetMaintenanceWindowTaskRequest(windowId, windowTaskId)
    def windowId: MaintenanceWindowId
    def windowTaskId: MaintenanceWindowTaskId
    def getWindowId: ZIO[Any, Nothing, MaintenanceWindowId] =
      ZIO.succeed(windowId)
    def getWindowTaskId: ZIO[Any, Nothing, MaintenanceWindowTaskId] =
      ZIO.succeed(windowTaskId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.GetMaintenanceWindowTaskRequest
  ) extends zio.aws.ssm.model.GetMaintenanceWindowTaskRequest.ReadOnly {
    override val windowId: MaintenanceWindowId =
      zio.aws.ssm.model.primitives.MaintenanceWindowId(impl.windowId())
    override val windowTaskId: MaintenanceWindowTaskId =
      zio.aws.ssm.model.primitives.MaintenanceWindowTaskId(impl.windowTaskId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.GetMaintenanceWindowTaskRequest
  ): zio.aws.ssm.model.GetMaintenanceWindowTaskRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ssm_3-5.17.166.2-sources.jar: zio/aws/ssm/model/GetMaintenanceWindowTaskRequest.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.{
  MaintenanceWindowTaskId,
  MaintenanceWindowId
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetMaintenanceWindowTaskRequest(
    windowId: MaintenanceWindowId,
    windowTaskId: MaintenanceWindowTaskId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.GetMaintenanceWindowTaskRequest = {
    import GetMaintenanceWindowTaskRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.GetMaintenanceWindowTaskRequest
      .builder()
      .windowId(MaintenanceWindowId.unwrap(windowId): java.lang.String)
      .windowTaskId(
        MaintenanceWindowTaskId.unwrap(windowTaskId): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.GetMaintenanceWindowTaskRequest.ReadOnly =
    zio.aws.ssm.model.GetMaintenanceWindowTaskRequest.wrap(buildAwsValue())
}
object GetMaintenanceWindowTaskRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.GetMaintenanceWindowTaskRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.GetMaintenanceWindowTaskRequest =
      zio.aws.ssm.model.GetMaintenanceWindowTaskRequest(windowId, windowTaskId)
    def windowId: MaintenanceWindowId
    def windowTaskId: MaintenanceWindowTaskId
    def getWindowId: ZIO[Any, Nothing, MaintenanceWindowId] =
      ZIO.succeed(windowId)
    def getWindowTaskId: ZIO[Any, Nothing, MaintenanceWindowTaskId] =
      ZIO.succeed(windowTaskId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.GetMaintenanceWindowTaskRequest
  ) extends zio.aws.ssm.model.GetMaintenanceWindowTaskRequest.ReadOnly {
    override val windowId: MaintenanceWindowId =
      zio.aws.ssm.model.primitives.MaintenanceWindowId(impl.windowId())
    override val windowTaskId: MaintenanceWindowTaskId =
      zio.aws.ssm.model.primitives.MaintenanceWindowTaskId(impl.windowTaskId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.GetMaintenanceWindowTaskRequest
  ): zio.aws.ssm.model.GetMaintenanceWindowTaskRequest.ReadOnly = new Wrapper(
    impl
  )
}
